% Single-bit Bit loading
%
% Initially written by:     Jan Vidar Rognsvg: Fall 2007    
%
% Last revised by:          Jan Vidar Rognsvg 	06.06.2008
%
% Input: Index of line for bit loading, PBO of all lines in the system
% Output: Bit rate of the line matching the system index, ratio of
% transmitted PSD vs fixed PSD
% 
% Ex: system=1;PBOx=[0 0 0];[R,PSDr]=bitload(system,PBOx);
function [R,PSDr] = bitload(system,PBOx)
tic
defVDSLu;
[Npsd,Hpsd,cap] = sys(PBOx,0);  % The channel characteristics 
N = Npsd(1:NF,system).';
H = Hpsd(1:NF,system).';
M = 10^(MARG/10);       % Margin compared to shannons limit   
NCR = M*N./H.^2;        % Signal-to-noise ratio with unity signal power
Pmax = 10^(Sipsd/10)*((FH-FL)*10^6); % Upper limit for transmitted power
P = 0;          %Total transmitted power
b = zeros(1,NF);
S = zeros(1,NF);
[NCRmin,k] = min(NCR);  
dS = NCR;
% Alternately bit loading till max power is reached
tic
while (Pmax > P )% && max(S)<10^(Sipsd/10)) % Continue till max power is reached
    b(k) = b(k)+1;          % Allocate bit to carrier
	S(k) = S(k) + dS(k);
    dS(k) = 2*dS(k);
	[dSmin,k] = min(dS);    % Update index for minimum NCR
	P = sum(S).*dF*1e6;     % Update transmitted power
end
R = sum(b)*dF;
PSDr = Sipsd-S;
toc
% Just for presentation:
NCRdB=10*log10(NCR);
SdB=10*log10(S);
figure(1)
subplot(2,1,1);
stairs(F,NCRdB,'r')
xlim([FL FH]);
title('NCR before iterative bit loading','FontSize',12)
ylabel('NCR, dBm/Hz','FontSize',12)
subplot(2,1,2);
Sipsds = Sipsd-PBOx(system);
%SdB=ones(1,NF)*Sipsd;
plot(F,SdB,'--')
stairs(F,SdB,'k')
xlim([FL FH]);
legend('Fixed Spectum','Bit loading')
title('PSD after iterative bit loading','FontSize',12)
xlabel('Frequency, MHz','FontSize',12)
ylabel('PSD, dBm/Hz','FontSize',12)
if system==1
    title1 = 'Transmitted spectrum  in L1 after bit loading';
else
    title1 = 'Transmitted spectrum  in L2 after bit loading';
end
figure(2)
Sip=Sipsd*ones(1,NF);
plot(F,Sip,'--');hold
stairs(F,SdB,'k');
stairs(F,NCRdB,'r:');hold
axis([FL FH floor(min(NCRdB)) ceil(max(SdB))])
title(title1,'FontSize',12);
xlabel('Frequency, MHz','FontSize',12)
ylabel('PSD, dBm/Hz','FontSize',12)
legend('Fixed spectrum','Bit loading','NCR')