%  Default input data for xDSL calculations (master version)
%  
%
%  Initially written by:		Nils Holte	spring 2001
%
%  Last revised by:             Jan Vidar Rognsvg	22.06.2008
%
%  Changed to meet VDSL standards.(12)-(16),(19),(23)
%
L=1;            %  Cable length in km (initial value)
LE=.5:.5:1;     %  Cable length vector
FL=3.75;        %  lower frequency im MHz
FH=5.2;         %  upper frequency im MHz
NF=336;         %  number of frequencies w/frequency spacing f=4.3125
MARG=5;         %  margin in dB relative to Shannon (3dB for TCM + impl.marg.)
BWEM=15;        %  Maximum bandwidth efficiency in bit/s/Hz
BWEmin=1;		%  Minimum bandwidth efficiency in bit/s/Hz
BWEstep=1;		%  Step size in bandwidth efficiency in bit/s/Hz
Reff=1;         %  Rate reduction due to overhead (CP, RS-code, ...)
%
%  Signal
%
Sipsd=-52;      %  Maximum output spectral density in dBm/Hz VDSL2 998 i ITU
PSD=0;          %  Transmitter output spectral density in dBm/Hz: 
                %   1:  ADSL/ADSL2/ADSL2+ upstream all digital (3 - 276 kHz)
                %   2:  ADSL/ADLS2/ADLS2+ upstream over ISDN (120 - 276 kHz)
                %   3:  ADSL downstream (254 - 1104 kHz)
                %   4:  ADSL2+ downstream (254 - 2208 kHz)
                %   10: VDSL upstream 997. Table B-4/G.993.2  Upstream Limit PSD masks for
                %       band plan 997. Plan B7-5.
                %   11: VDSL upstream 998
                %   12: VDSL downstream 997. Table B-5/G.993.2  Downstream Limit PSD masks
                %       for band plan 997. Plan B7-5.
                %   13: VDSL downstream 998
                %   20: VDSL2 upstream 997E30. Table B-4/G.993.2  Upstream Limit PSD masks for
                %       band plan 997. Plan B7-10. 
                %   21: VDSL2 upstream 998
                %   22: VDSL2 downstream 997E30. Table B-5/G.993.2  Downstream Limit PSD masks
                %       for band plan 997. Plan B7-10
                %   23: VDSL2 downstream 998              
                %

%
AttMod=1;       %
				%   1:	attenuation proportional to sqrt(f)
				%   2:  attenuation given as a table for .4 mm cable
				%   3:  attenuation given as a table for .6 mm cable
				%   4:  ITU attenuation model .4 mm cable (valid at all frequencies)
				%   5:  SYMCAB attenuation model .4 mm cable 
				%   6:  SYMCAB attenuation model .6 mm cable
				%   7:  SYMCAB attenuation model .9 mm cable
alfa1dB=22.5;	%  Attenuation in dB at 1 MHz  (AttMod=1)
Falfa=[.1 .2 .35 .7 1 1.4 2  2.8 4];
				%  Frequency vector in MHz for attenuation (AttMod=2)
alfaM=zeros(1,length(Falfa));					
alfaM(2,:)=[9.11 11.15 13.65 18.74 22.41 26.52 31.69 37.5 44.82];
				%  Attenuation vector for .4 mm cable in dB/km (AttMod=2)
                % alfaM(3,:)=[5.02 6.67 8.79 12.47 14.86 21.01 29.74]
alfaM(3,:)=[5.10 6.78 8.93 12.67 15.10 17.87 21.35 25.27 30.20];
				%  Attenuation vector for .6 mm cable in dB/km (AttMod=3)
beta1=10*pi;	%  Phase constant in rad/km at 1 MHz
BcoOn=0;
				%	0:  Power backoff off
				%   1:  Power backoff table no 1 (0.4 mm cable)
				%   2:  Power backoff table no 2 (0.6 mm cable)
BcoLV1=[.152 .291 .430 .569 .708 .848];		% Table for 0.4 mm ADSL
BcoLV2=[.253 .484 .717 .949 1.181 1.413];	% Table for 0.6 mm ADSL
				%  Vector containing limits of length intervals in
				%  power backoff table
BcodBV=[12 10 8 6 4 2 0]; 
				%  Vector containing backoff in dB for the transmitter of 
				%  the disturbed system. BcodBV(1) is backoff for the interval
				%  0 < L < BcoLV(1). The length of BcodBV should be one element 
				%  larger than BcoLV. The last element of BcodBV is backoff for
				%  lengths beyond the last length in BcoLV
%
%  White noise
%
AWGNon=1;		%	0:	No white noise
				%	1:  Additive white noise with specified spectral density
WNpsd=-140;		%  White noise spectral density in dBm/Hz
%
%  self NEXT
%
NEon=0;			%	0:  self NEXT off
				%	1:  50 pair empirical model for self NEXT 
				%	2:  specified NEXT power sum
NPAN=49;		%  Number of disturbing pairs for self NEXT (NEon=1)
NEXT1ps=40.0;	%  NEXT power sum in dB at 1 MHz for NEon=2
%
%  self FEXT
%
FEon=2;			%	0:  self FEXT off
				%	1:  50 pair empirical model for self FEXT 
				%	2:  specified FEXT power sum
LFEdistRat=100; % Ratio between length of disturbed pair and disturbing pairs in
				% Always use LFEdistRat=100 for downstream 
NPAF=49 ;       % Number of disturbing pairs for self FEXT (FEon=1)					
FEXT1ps=45;     % FEXT power sum in dB at 1 MHz and 1 km for FEon=2
%
%  Alien NEXT from SHDSL
%
SHDSLonV=[0 0];	%	Vector for multiple cases (speeds) of SHDSL
				%	Each element of SHDSLon vector:
				%	0: SHDSL off
				%	1: Alien NEXT from SHDSL, 50 pair empirical NEXT model
				%	2: Alien NEXT from SHDSL, specified NEXT power sum
LSHDSLmaxV=[10 10];	%  Maximum range in km of SHDSL system (vector)					
LSHDSLsepV=[0 0];	%  Separate distance in km from alien NEXT transmitter to receiving pair (vector)
PBOSHV=[0 0]	;	%  Power backoff of SHDSL in dB (vector)
RSHDSLV=[1.0 2.3];	%  Rate of disturbing SHDSL system in MHz (vector)
NPASHV=[10 10]	;	%  Number of disturbing pairs used for SHDSL (SHDSLon=1) (vector)
NEXT1psSHV=[40 40];	%  NEXT power sum in dB at 1 MHz for SHDSLon=2 (vector)
SHDSLmodV=[16 32];	%  Type of modulation in SHDSL (vector)
                    %   16:  16 PAM
                    %   32:  32 PAM
%
%  Alien NEXT from HDSL
%
HDSLonV=0;		%	Vector for multiple cases (crosstalk model and speed) of HDSL
				%	Each element of HDSLon vector:
				%	0:   HDSL off
				%	xy:  NEXT model no x, spectral mask no y
				%	x=1: 50 pair empirical NEXT model
				%	x=2: specified NEXT power sum
				%	y=1: 1 pair HDSL system
				%	y=2: 2 pair HDSL system
				%	y=3: 3 pair HDSL system
LHDSLmaxV=[1 10];	%  Maximum range in km of HDSL system (vector)						
LHDSLsepV=[0 0];	%  Separate distance in km from alien NEXT transmitter to receiving pair (vector)
PBOHDSLV=[0 0];		%  Power backoff of HDSL in dB (vector)
NPAHDSLV=[10 10];	%  Number of disturbing pairs used for HDSL (x=1) (vector)
NEXT1psHDSLV=[40 40];	%  NEXT power sum in dB at 1 MHz for x=2 (vector)
%
%  Alien NEXT from E1-systems (2.048 Mbit/s) 
%
E1on=0;         %	0: E1 systems off
				%	1: 50 pair empirical NEXT model
				%	2: specified NEXT power sum
LE1max=1;		%  Maximum range in km of E1 system 
LE1sep=0;		%  Separate path in km from alien NEXT transmitter to receiving pair
PBOE1=0	;		%  Power backoff of E1 systems in dB
NPAE1=10;		%  Number of disturbing pairs used for E1 (E1on=1)
NEXT1psE1=40.0;	%  NEXT power sum in dB at 1 MHz for E1on=2
%
%  Alien NEXT from ISDN (160 kbit/s 2B1Q)
%
ISDNon=0;		%	0: ISDN systems off
				%	1: 50 pair empirical NEXT model
				%	2: specified NEXT power sum
LISDNmax=10	;	%  Maximum range in km of ISDN system 
LISDNsep=0;		%  Separate distance in km from alien NEXT transmitter to receiving pair
PBOISDN=0;		%  Power backoff of ISDN systems in dB
NPAISDN=10;		%  Number of disturbing pairs used for ISDN (ISDNon=1)
NEXT1psISDN=40.0;	%  NEXT power sum in dB at 1 MHz for ISDNon=2
%
%  Alien NEXT (multicarrier)
%
AliNEon=0;		%	0: Alien NEXT off (multicarrier)
				%	1: Alien Next on, 50 pair empirical model
				%	2: Alien NEXT on, specified 99% NEXT power sum
LAliNE=0;		%  Distance in km from alien NEXT transmitter to receiver
FLAliNE=.1;		%  Lower frequency in MHz, alien NEXT system
FHAliNE=1;		%  Upper frequency in MHz, alien NEXT system
AliNEpsd=-40;	%  Alien NEXT source power spectral density in dBm/Hz
NPAliNE=10;		%  Number of disturbing pairs contributing to alien NEXT
NEAlips=40;		%  NEXT power sum in dB at 1 MHz for model no 2
%
%  Alien NEXT from a frequency mask representing a combination of systems
%
COMBon=0;		%	0 :  Combined systems off
				%	xy:  NEXT model no x, spectral mask no y
				%	x=1: 50 pair empirical NEXT model
				%	x=2: specified NEXT power sum
				%	y=0: ADSL downstream
				%	y=1: ADSL downstream + 2-way systems 
				%	y=2,6,10: ADSL upstream 
				%	y=3,7,11: ADSL upstream + 2-way systems, short loop 
				%	y=4,8,12: ADSL upstream + 2-way systems, medium loop 
				%	y=5,9,13: ADSL upstream + 2-way systems, long loop 
				%	y=2,3,4,5: ADSL upstream using split band
				%	y=6,7,8,9: ADSL upstream using overlapping bands
				%	y=10,11,12,13: ADSL upstream over POTS
				%	y=14: Frequency template for two-way systems
                %   y=15: ADSL downstream                     
                %   y=16: VDSL2 997 upstream
                %   y=17: VDSL2 997 downstream
                %   y=18: VDSL 997 upstream
                %   y=19: VDSL 997 downstream
                %
LCOMB=0;		%  Distance in km from alien NEXT transmitter to receiver
PBOCOMB=0;		%  Power backoff of COMB in dB
NPACOMB=10;		%  Number of disturbing pairs used for COMB (x=1)
NEXT1psCOMB=40.0;	%  NEXT power sum in dB at 1 MHz for x=2
%
%  Alien FEXT (multicarrier)
%
AliFEon=0;		%	0   : Alien FEXT off (multicarrier)
				%	1, 5: Alien FEXT VDSL into ADSL downstream
				%	2, 6: Alien FEXT ADSL into VDSL downstream
				%	3, 7: Alien FEXT VDSL into ADSL upstream
				%	4, 8: Alien FEXT ADSL into VDSL upstream
				%  1,2,3,4: 99% FEXT power sum is specified
				%  5,6 7,8: Worst case FEXT model
LAsub=1;		%  Distance in km from ADSL DSLAM to VDSL DSLAM
LAdistRat=100;	%  Ratio in % between the actual length of the FEXT interferece path and
				%  the length of the FEXT interference path when all subscriber units
				%  (both ADSL and VDSL) are in the same position (relevant for upstream only)  
FLAliFE=.1;		%  Lower frequency in MHz, alien FEXT system
FHAliFE=1;      %  Upper frequency in MHz, alien FEXT system
AliFEpsd=-40;	%  Alien FEXT source power spectral density in dBm/Hz
NPAliFE=10;		%  Number of disturbing pairs contributing to alien FEXT
FEAlips=35.2;	%  FEXT power sum in dB at 1 MHz 
%
%	ETSI noise models
%
ETSIon=0;		%	0:	No ETSI test noise model
				%	1:  ETSI noise test model A
				%	2:	ETSI noise test model B
				%	3:	ETSI noise test model A without RF noise tones
				
%
%  Default limits for plots
%
LEM=LE(length(LE));	%  Max cable length in plots
RAM=10;				%  Max Rate in plots
%
%
%  Calculate derived parameters
%
initial
