% Iterative water-filling
%
% Initially written by:     Jan Vidar Rognsvg: Spring 2008    
%
% Last revised by:          Jan Vidar Rognsvg 	22.06.2008
%
% Input: PBO of all lines in the system
% Output: Bit rates of all lines in the system 
% 
% ex: PBOx = [0 0 0]; [R]=itwaterfill(PBOx)
function [R]=itwaterfill(PBOx)
tic
defVDSLu;
% Generate FEXT matrix
FEgen;
XFE = -10*log10(FEAV*randn^2);
X = sqrt(10^(-XFE(2,1)/10)/FEAV(2,1));
% Include next line if nominal FEXT coupling is desired
XFE = 0;
l=size(PBOx,2);
% Preallocate arrays to increase speed:
R=zeros(1,l);
PBOtmp=zeros(NF,l);
for i=1:l
    PBOtmp(1:NF,i)=PBOx(i);
end
[Ntmp,Htmp,Rf]=sys(PBOtmp,0);Rf;       % Finds rate at fixed PSD for presentation
[Npsd,H,Rwtd]=sys(PBOtmp,XFE);Rwtd;       % Finds rate at fixed PSD for presentation
for j = 1 : 10
    for i = 1 : l
        if ~(j == 1 && i == 1)% Let simulation start at disturbing system
            PBOtmp(1:NF,i) = PBOx(i);
            [R(i),cap,PSDr,SNR] = waterfillfast(i,PBOtmp,Rwtd,XFE);
            PBOtmp(1:NF,i) = PSDr;
            if i==1
                PSDrw=PSDr;
                capw=cap;
            end
        end
    end
end
toc
figure(1)
stem(R,':');
hold
stem(Rf,'k')
axis([0 l+1 0 ceil(max(R)+1)])
title('Capacity in systems prior and after water-filling','FontSize',12)
xlabel('System index','FontSize',12)
ylabel('Capacity, Mbit/s','FontSize',12)
legend('Water-filling','Fixed spectrum')

figure(2)
stairs(F,Sipsd-PSDrw)
hold
plot(F,ones(1,NF)*Sipsd,'--')
xlim([FL FH])
ylim([Sipsd-ceil(max(PSDrw)) Sipsd-floor(min(PSDrw))])
title('Transmitted Power Spectral Density in R1','FontSize',12)
xlabel('Frequency, MHz','FontSize',12)
ylabel('PSD, dBm/Hz','FontSize',12)
legend('Water-filling','Fixed spectrum')

NSRdB = 10*log10(1./SNR);
stairs(F,NSRdB)
ylim([floor(min(NSRdB)) Sipsd-floor(min(PSDrw))])