% Rate region based on iterative water-filling
%
% Initially written by:     Jan Vidar Rognsvg: Spring 2008    
%
% Last revised by:          Jan Vidar Rognsvg 	22.06.2008
%
% Input: PBO of all lines in system
% Output: Bit rates at IWF at given rate constraints, bit rates at SSM.
%
% ex: PBOx=[0 0 0];
%[R,cap]=itwaterfillRR(PBOx);
function [Rtot,cap]=itwaterfillRR(PBOx)
tic
defVDSLu;
l = size(PBOx,2);
% Preallocate arrays to increase speed:
R = zeros(1,l);
PBOtmp = zeros(NF,l);
for i = 1 : l
    PBOtmp(1:NF,i) = PBOx(i);
end
[Npsd,Hpsd,cap] = sys(PBOtmp,0); % Finds cap at fixed PSD
maxRate = ceil(max(cap))+1;
Rtot = zeros(l,maxRate+1);
for k = 0:maxRate % Uses specified Rwtd for disturbing systems
    Rwtd = ones(1,l)*k; % Rwtd for system 1 always infinite.
    for j = 1 : 5   %Number of iterations
        for i = 1 : l   % Number of lines
            if ~(j == 1 && i == 1)% Let simulation start at disturbing system
                PBOtmp(1:NF,i) = PBOx(i);
                [R(i),cap,PBO] = waterfillfast(i,PBOtmp,Rwtd,0);
                PBOtmp(1:NF,i) = PBO.';
            end
        end
    end
    Rtot(1:l,k+1) = R.';
    for i = 1 : l
        PBOtmp(1:NF,i) = PBOx(i);
    end
end
toc
figure(3)
xlim = ([0 20]);
ylim = ([0 25]);
plot(Rtot(2,1:maxRate+1),Rtot(1,1:maxRate+1),'k+-')
hold
for i = 3 : l
    plot(Rtot(i,1:maxRate+1),Rtot(1,1:maxRate+1),'kx-')
end
legend('L2','L3')
%axis([min(0) ceil(max(Rtot(1,1:maxRate+1)))+3 min(min(Rtot(2,1:maxRate+1),Rtot(3,1:maxRate+1))) ceil(max(Rtot(2,1:maxRate+1),Rtot(3,1:maxRate+1)))])
if (l==2)
    title('Rate Region, Rate constraint in L2','FontSize',12)
    xlabel('Capacity in L2, Mbps','FontSize',12)
else
    title('Rate Region, Rate constraint in disturbing lines','FontSize',12)
    xlabel('Capacity in disturbing lines, Mbps','FontSize',12)
end
ylabel('Capacity in L1, Mbps','FontSize',12)

