% System parameters, capacity at SSM
%
% Initially written by:     Jan Vidar Rognsvg: Spring 2008    
%
% Last revised by:          Jan Vidar Rognsvg: 22.06.2008    
%
% Input: PBO of all lines in system, (crosstalk coefficient matrix).
% Output: Total noise spectrum in all lines, channel attenuation in all
% lines, capacity at SSM. 
%
% Ex: PBO = [0 0 0]; XFE=0;
% [Spsd,Npsd,H,cap] = sys(PBO,XFE)
function[Npsd,H,cap]=sys(PBOx,XFE)
defVDSLu;
dist = [0.8 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5]; % Sets length for all lines.
l = size(PBOx,2);
% If PBOx is a vector -> Create matrix:
if isvector(PBOx)
    for j=1:size(PBOx,2)
        PBOx(1:NF,j)=PBOx(1,j)*ones(1,NF).';
    end
end
% If XFE is not applied -> Create matrix of FEXT1ps:
if length(XFE)<l
    XFE=FEXT1ps.*ones(l);
end
for i = 1 : l % Finds total noise for user i and his capacity at fixed spectrum
    L = dist(i);
    FEtot = zeros(1,NF);
    for j = 1 : l % Finds FEXT from disturbing user j.
        if j ~= i
            FEXT1ps = XFE(i,j); 
            FEXT1ps = FEXT1ps+3*(abs(i-j)-1);% Lines further away disturb less. Not realistic number!
            LFEdistRat = dist(j)/L*100;
            PBOk = PBOx(1:NF,j).';
            fext;   % Retrieves crosstalk from pair j, FE
            FEtot = FEtot+FE;
        end
    end
    PBOs = PBOx(1:NF,i).';
    sig;                      % Retrieves attenuated signal, S
    whnoi;                    % Retrieves noise, WN
    Npsd(1:NF,i) = WN*ones(1,NF)+FEtot;
    N = Npsd(1:NF,i).';
    y = log2(1+AMARG*S./N);   % Shannon bound with margin
    y = floor(y/BWEstep)*BWEstep;% Round down to nearest step (adaptive modulation)
    y(y>BWEM) = BWEM;         % Maximum bandwidth efficiency limitation
    y(y<BWEmin-1.e-6) = 0;    % Minimum bandwidth efficiency limitation
    cap(i) = sum(y)*dF*Reff;
    H(1:NF,i) = sqrt(exp(-2*L*alfa));
end