% Top filling
%
% Initially written by:     Jan Vidar Rognsvg: Spring 2008    
%
% Last revised by:          Jan Vidar Rognsvg 	22.06.2008
%
% Input: Index of line to be water-filled, PBO of all lines in system,
% capacity constraints for each line, (crosstalk coefficient matrix)
% Output: Bit rate, capacity at SSM, ratio of transmitted PSD vs fixed PSD,
% output signal-to-noise ratio.
%
% Ex: system=2;PBOx=[0 0 0];Rwtd=[15 15 15];XFE=0;
% [R,cap,PSDr,SNR]=topfill(system,PBOx,Rwtd,XFE);
function [R,cap,PSDr,SNR]=topfill(system,PBOx,Rwtd,XFE)
tic
defVDSLu;
% Lines: Ignores extra lines if size(dist)>size(PBOx,2)
% If PBOx is a vector -> Create matrix:
if isvector(PBOx)
    for j=1:size(PBOx,2)
        PBOx(1:NF,j)=PBOx(1,j)*ones(1,NF).';
    end
end
[Npsd,Hpsd,cap] = sys(PBOx,XFE);
N = Npsd(1:NF,system).';
H = Hpsd(1:NF,system).';
M = 10^(-MARG/10);      % Margin compared to shannons limit
SNR = M*H.^2./N;        % Signal-to-noise ratio with unity signal power
Sipsds = Sipsd-PBOx(1,system);  % Adjust for PBO in signal(always fixed)
Pmax = 10.^(Sipsds/10)*(FH-FL)*10^6;  %  Total transmitted power. [mW]
b=zeros(1,NF);
S=zeros(1,NF);
P=0;
R=0;
Rmax=Rwtd(system);
PSDcon = 10^((Sipsds+0)/10);
for i = 1 : NF
    while (S(NF-i+1)<PSDcon && b(NF-i+1)<BWEM && P<Pmax && R<Rmax)
        b(NF-i+1) = b(NF-i+1)+1;           % Add one bit
        S(NF-i+1) = (2^b(NF-i+1)-1)/SNR(NF-i+1);% Update PSD
        P = sum(S)*dF*1e6;
        R = sum(b)*dF;
        b(NF-i+1);
    end
end
if(R<Rmax)
    warning('Target rate can not be reached with this PSD constraint!')
end

SdB = 10*log10(S);    % Transmitted Spectrum in dBm/Hz
PSDr = Sipsd-SdB;      % Fixed spectrum compared to the transmitted spectrum

% For presentation
% Comparison in dBm:
figure(4)
SfdB=ones(1,NF)*Sipsds;
plot(F,SfdB,'--')
hold;
stairs(F,SdB,'k')
NSRdB = 10*log10(1./SNR);
stairs(F,NSRdB,'r:')    
legend('Fixed Spectum','Transmitted Spectrum','NCR')
axis([FL FH floor(min(NSRdB-2)) ceil(max(max(NSRdB,SdB))+2)])
title('Top-Filling of disturbing line','FontSize',12)      
xlabel('Frequency, MHz','FontSize',12)
ylabel('PSD, dBm/Hz','FontSize',12)

% Comparison in mW:
figure(5)
Sf=ones(1,NF)*10^(Sipsds/10);
plot(F,Sf,'--')
hold;
stairs(F,S,'k')
stairs(F,1./SNR,'r:')    
legend('Fixed Spectum','Transmitted spectrum','NCR')
axis([FL FH 0 1.1*(max(max(1./SNR,S)))])
title('Transmitted Power Spectral Density in chosen system','FontSize',12)      
xlabel('Frequency, MHz','FontSize',12)
ylabel('PSD, mW/Hz','FontSize',12)

% Bit loading:
figure(6)
stairs(F,b,'k')
legend('Top-filling')
axis([FL FH 0 max(b+1)])
title('Bit Loading - Bandwidth Efficiency','FontSize',12)      
xlabel('Frequency, MHz','FontSize',12)
ylabel('Bandwidth efficiency, b/s/Hz','FontSize',12) 