% Water-filling (no presentations)
%
% Initially written by:     Jan Vidar Rognsvg: Spring 2008    
%
% Last revised by:          Jan Vidar Rognsvg 	22.06.2008
%
% Input: Index of line to be water-filled, PBO in all lines in system,
% capacity constraints for each line, (crosstalk coefficient matrix)
% Output: Bit rate, capacity at SSM, ratio of transmitted PSD vs fixed PSD,
% output signal-to-noise ratio.
% 
% Ex: system=1;PBOx=[0 0 0];Rwtd=[0 15 15];XFE=0;
% [R,cap,PSDr,SNR]=waterfill(system,PBOx,Rwtd,XFE);
function [R,cap,PSDr,SNR]=waterfillfast(system,PBOx,Rwtd,XFE)
defVDSLu;
if system ~= 1
    % Include next line to permit top filling (waterfillfast).
    %[R,cap,PSDr,SNR]=topfillfast(system,PBOx,Rwtd,XFE);return
    if (Rwtd(system)==0)
        R=0;
        PSDr=ones(1,NF).'*inf;
        cap=0;
        SNR=0;
        return
    end
end
% Lines: Ignores extra lines if size(dist)>size(PBOx,2)
[Npsd,Hpsd,cap] = sys(PBOx,XFE);
N = Npsd(1:NF,system).';
H = Hpsd(1:NF,system).';
M = 10^(-MARG/10);       % Margin compared to shannons limit
SNR = M*H.^2./N;    % Channel signal-to-noise ratio with unity signal power
Sipsds = Sipsd-PBOx(1,system);      % Adjust for PBO in own signal(always fixed)
% Waterfilling, limited by Pmax, PSDcon & Rwtd.
Pmax = 10.^(Sipsds/10)*(FH-FL)*10^6;% Total transmitted power. [mW]
PSDcon = 10^((Sipsds+3)/10);        % PSC constraint.
tol = 0.01*10^((Sipsds-Sipsd)/10);  % Tolerance to inaccuracy in power allocation.
SNRmean=10*log10(mean(SNR));        % To adjust initial waterline for extreme SNR in disturbing lines.
% To ensure convergence
if (system==1)
    q = 1;      
else            % Slow down convergence, want R close to Rwtd.
    q = 10^(0.1*(SNRmean-96)); 
    q = q*10^(5-2*Rwtd(system)/10);   % 10-> far off 100->slow
    q = max(q,10);
end
K = min(1./SNR)+Pmax/((FH-FL)*10^6*q);   % Initial waterline
P = max(K-1./SNR,0);    % Transmitted PSD after waterfilling
% Deduct transmitted PSD where no integer bit has been alllocated
b = log2(1+P.*SNR);     % Number of bits in each subchannel
b = floor(b/BWEstep)*BWEstep;   % BWEstep=1Hz, -> b=floor(b)
b(b>BWEM) = BWEM;       % Max bandwidth efficiency
Pb = (2.^b-1)./SNR;     % Transmitted PSD after bitloading
Ptot = sum(Pb)*dF*1e6;  % Total power for current bitloading
R = sum(b)*dF;          % Transmission rate in Mbps
iter=0;
% Gradual water-filling
% repeat while (Powerdiff>tolerance & b<BWEM in some carrier & R<Rwanted)
while abs(Pmax-Ptot)>tol && (min(b)~=BWEM||Ptot>Pmax+tol) && (R<Rwtd(system)||system==1) && (iter<100)
    K=K+(Pmax-Ptot)/((FH-FL)*10^6*q); % Increase K to reach Pmax
    iter=iter+1;
    P=max(K-1./SNR,0);
    P=min(P,PSDcon); %PSD constraint
    b=log2(1+P.*SNR);
    b=floor(b/BWEstep)*BWEstep;    
    b(b>BWEM)=BWEM;
    Pb=(2.^b-1)./SNR;
    Ptot=sum(Pb)*dF*1e6;
    R=sum(b)*dF;
    % PSD constraint: Stops when least value of P equals PSDcon
    if (min(P)==PSDcon && Ptot<Pmax)
        Pmax=Ptot;
    end
end 
% In case of no convergence
if(iter==100)
    warning('Waterfill exceeds number of iterations!')
    Constraint=Rwtd(system);
    while(Ptot>Pmax)
        [tmp,i] = max(Pb);
        b(i) = b(i)-1;
        Pb=(2.^b-1)./SNR;
        Ptot=sum(Pb)*dF*1e6;
    end
    R=sum(b)*dF;
end
PbdB=10*log10(Pb);
PSDr=Sipsd-PbdB;   % Fixed spectrum compared to the transmitted spectrum